onRequest method
Called when the request is about to be sent.
Implementation
@override
void onRequest(
dio.RequestOptions options,
dio.RequestInterceptorHandler handler,
) {
getProxyLogInterceptor().onRequest(options, handler);
}
Called when the request is about to be sent.
@override
void onRequest(
dio.RequestOptions options,
dio.RequestInterceptorHandler handler,
) {
getProxyLogInterceptor().onRequest(options, handler);
}