LogLevelInterceptor class

日志级别拦截器

Constructors

LogLevelInterceptor(LogLevel logLevel)

Properties

hashCode int
The hash code for this object.
no setterinherited
logLevel LogLevel
支持打印的级别,参考LogLevel
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onIntercept(dynamic message, LogLevel level) bool
level 参考LogLevel
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited