LogMethodType enum

日志输出方式 速度 print > debugPrint >stderr

Inheritance
Available extensions

Values

print → const LogMethodType

同步

const LogMethodType(0)
debugPrint → const LogMethodType

异步+长字符串拆分

const LogMethodType(1)
stderr → const LogMethodType

同步

const LogMethodType(2)

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<LogMethodType>
A constant List of the values in this enum, in order of their declaration.