LogUtils class

LogUtils 优势1,先判断环境,是不是应该打印,再执行回调,以回调的形式能避免业务转换或者获取其他变量,包括对象的toString()等方法带来的消耗 优势2,可配置各种数据结构的解析,不单纯是支持string,支持各种数据自定义,请参考parser

Constructors

LogUtils()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

config LogConfig
final

Static Methods

logD(dynamic message, {String? tag, Object? error, StackTrace? stackTrace}) → void
message:支持function,eg. ()=>xxx
logE(dynamic message, {String? tag, Object? error, StackTrace? stackTrace}) → void
message:支持function,eg. ()=>xxx
logI(dynamic message, {String? tag, Object? error, StackTrace? stackTrace}) → void
message:支持function,eg. ()=>xxx
logV(dynamic message, {String? tag, Object? error, StackTrace? stackTrace}) → void
message:支持function,eg. ()=>xxx
logW(dynamic message, {String? tag, Object? error, StackTrace? stackTrace}) → void
message:支持function,eg. ()=>xxx