TalkerLogger class

使用talker_flutter 实现

Implemented types

Constructors

TalkerLogger()
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
logger → Talker
这里共享一个就行了,避免缓存更多的Logger
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getLoggerWidget() Widget
override
logD(String tag, Object log) → void
override
logE(String tag, Object log) → void
override
logI(String tag, Object log) → void
override
logV(String tag, Object log) → void
override
logW(String tag, Object log) → void
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited