HttpLogInterceptor class
网络日志拦截器(基于 TalkerDioLogger 包装)
Constructors
Properties
- error ↔ bool
-
Print error message
getter/setter pairinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- logPrint ↔ void Function(Object object)
-
Log printer; defaults print log to console.
In flutter, you'd better use debugPrint.
you can also write log in a file, for example:
getter/setter pairinherited
- request ↔ bool
-
Print request
RequestOptionsgetter/setter pairinherited - requestBody ↔ bool
-
Print request data
RequestOptions.datagetter/setter pairinherited - requestHeader ↔ bool
-
Print request headers
RequestOptions.headersgetter/setter pairinherited - requestUrl ↔ bool
-
Print request URL
RequestOptions.urigetter/setter pairinherited - responseBody ↔ bool
-
Print
Response.datagetter/setter pairinherited - responseHeader ↔ bool
-
Print
Response.headersgetter/setter pairinherited - responseUrl ↔ bool
-
Print
Response.realUrigetter/setter pairinherited - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
asTypeOrDefault<
T> (T createFactory()) → T -
getProxyLogInterceptor(
) → LogInterceptor -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
onError(
DioException err, ErrorInterceptorHandler handler) → void - Called when an exception was occurred during the request.
-
onRequest(
RequestOptions options, RequestInterceptorHandler handler) → void - Called when the request is about to be sent.
-
onResponse(
Response response, ResponseInterceptorHandler handler) → void - Called when the response is about to be resolved.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited